@@ -1,8 +1,6 @@
 from sympy import *
 
 
-def main():
-    """
 from IPython.display import IFrame
 from urllib.request import urlopen
 from zipfile import ZipFile
@@ -21,11 +19,10 @@ def download_and_unzip(url, extract_to='.'):
     zipfile.extractall(path=extract_to)
 
 
-url = 'https://drive.google.com/u/0/uc?id=1Q1e1ovKOn_5jzO7k1E_P8ikTIdW7DhhQ&export=download'
+def load():
+    url = 'https://drive.google.com/u/0/uc?id=1Q1e1ovKOn_5jzO7k1E_P8ikTIdW7DhhQ&export=download'
+    download_and_unzip(url, extract_to='.')
 
-download_and_unzip(url, extract_to='.')
-"""
-    pass
 
 
 def get_inversions(d: dict):
